@@ -10,8 +10,8 @@ import numpy as np
 import warnings
 import pdb
 
-# from cosmoboost import COSMOBOOST_DIR
-# sys.path.insert(0, COSMOBOOST_DIR)
+from cosmoboost import COSMOBOOST_DIR
+sys.path.insert(0, COSMOBOOST_DIR)
 
 from .lib import FileHandler as fh
 from .lib import FrequencyFunctions as ff
